# preserve [![NPM version](https://badge.fury.io/js/preserve.svg)](http://badge.fury.io/js/preserve)

> Temporarily substitute tokens in the given `string` with placeholders, then put them back after transforming the string.

Useful for protecting tokens, like templates in HTML, from being mutated when the string is transformed in some way, like from a formatter/beautifier.

For example, say you want to use [js-beautify] on this string of html: `<ul><li><%= name %></li></ul>`:

**Without `preserve`**

The variable is now unusable, and the formatting is wrong.

```html
<ul>
  <li>
    <%=n ame %>
  </li>
</ul>
```

**With `preserve`**

Correct.

```html
<ul>
  <li><%= name %></li>
</ul>
```

For the record, this is just a random example, I've had very few issues with js-beautify in general. But with or without js-beautify, this kind of token mangling does happen sometimes when you use formatters, beautifiers or similar tools.

## Install
#### Install with [npm](npmjs.org)

```bash
npm i preserve --save
```

## Run tests

```bash
npm test
```

## API
### [Tokens](index.js#L23)

Create an instance of `Tokens` with a `regex` for the tokens you wish to preserve.

* `re` **{RegExp}**: Matching regex for the tokens you want to preserve.    

```js
var Tokens = require('preserve');
var tokens = new Tokens(/<%=\s*[^>]+%>/g);
```

### [.before](index.js#L53)

Replace tokens in `str` with a temporary, heuristic placeholder.

* `str` **{String}**    
* `returns` **{String}**: String with placeholders.  

```js
tokens.before('<div><%= name %></div>');
//=> '<div>__ID1__</div>'
```

### [.after](index.js#L77)

Replace placeholders in `str` with original tokens.

* `str` **{String}**: String with placeholders    
* `returns` **{String}** `str`: String with original tokens.  

```js
tokens.after('<div>__ID1__</div>');
//=> '<div><%= name %></div>'
```

## Contributing
Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/jonschlinkert/preserve/issues)

## Author

**Jon Schlinkert**
 
+ [github/jonschlinkert](https://github.com/jonschlinkert)
+ [twitter/jonschlinkert](http://twitter.com/jonschlinkert) 

## License
Copyright (c) 2014 Jon Schlinkert, contributors.  
Released under the MIT license

***

_This file was generated by [verb-cli](https://github.com/assemble/verb-cli) on November 01, 2014._

[js-beautify]: https://github.com/beautify-web/js-beautify